/**
 * {@link LightAdjustmentProcessor} に指定可能なオプション
 */
interface LightAdjustmentProcessorOptions {
    /**
     * AGCWD の論文 (Efficient Contrast Enhancement Using Adaptive Gamma Correction With Weighting Distribution) に
     * 登場する調整パラメータ（非負の数値）。
     * この値が大きいほど画像のコントラストが強調される傾向がある。
     *
     * デフォルト値は 0.5
     */
    alpha?: number;
    /**
     * ライト調整処理の度合い。
     *
     * AGCWD によるライト調整処理適用前後の画像の混合割合（パーセンテージ）で、
     * 0 なら処理適用前の画像が、100 なら処理適用後の画像が、50 ならそれらの半々が、採用されることになる。
     *
     * デフォルト値は 50
     */
    adjustmentLevel?: number;
    /**
     * AGCWD によるライト調整後に画像に適用するシャープネス処理の度合い。
     *
     * シャープネス処理適用前後の画像の混合割合（パーセンテージ）で、
     * 0 なら処理適用前の画像が、100 なら処理適用後の画像が、50 ならそれらの半々が、採用されることになる。
     *
     * 0 を指定した場合にはシャープネス処理が完全にスキップされて、処理全体がより高速になる。
     *
     * デフォルト値は 20
     */
    sharpnessLevel?: number;
    /**
     * 処理後の画像の最低の明るさ (HSV の V の値、 0 ~ 255 の整数）。
     *
     * デフォルト値は 0
     */
    minIntensity?: number;
    /**
     * 処理後の画像の最大の明るさ (HSV の V の値、 0 ~ 255 の整数）。
     *
     * デフォルト値は 255
     */
    maxIntensity?: number;
    /**
     * AGCWD の論文に登場する、映像のフレーム間の差異を検知する際の閾値（0.0 ~ 1.0 の数値）
     *
     * 新しい映像フレームが以前のものと差異があると判定された場合には、
     * ライト調整用の変換テーブルが更新されることになる。
     *
     * 値が小さくなるほど、微細な変化でテーブルが更新されるようになるため、
     * より適切な調整が行われやすくなるが、その分処理負荷は高くなる。
     *
     * 0 を指定した場合には毎フレームで更新が行われるようになる。
     *
     * デフォルト値は 0.05
     */
    entropyThreshold?: number;
    /**
     * ライト調整の際に基準とする画像領域を指定するマスクの取得方法。
     *
     * デフォルトでは {@link UniformFocusMask} が使用される。
     *
     * {@link UniformFocusMask} は画像全体を均一に扱って調整を行うため、
     * 例えば逆光時には人物が暗いままになってしまうことがある。
     * その際には {@link SelfieSegmentationFocusMask} を使用すれば、
     * 人物部分のみがマスクとして取得され、そこの明るさが適切になるような調整が行われるようになる。
     *
     * なおマスクの値は「画像のライトをどのように調整するか（より具体的には明るさ変換テーブルをどう構築するか）」を
     * 左右するだけで、調整処理自体は常に画像全体に対して行われる。
     *
     * マスク取得は毎フレームではなく、最後にマスクを取得したフレームに対して、
     * {@link LightAdjustmentProcessorOptions.entropyThreshold} の閾値を超える変化が検知された時にのみ行われる。
     */
    focusMask?: FocusMask;
}
/**
 * 映像トラックにライト（明るさ）調整処理を適用するためのプロセッサ
 *
 * 調整処理は AGCWD (Efficient Contrast Enhancement Using Adaptive Gamma Correction With Weighting Distribution) という
 * アルゴリズムをベースにしています
 */
declare class LightAdjustmentProcessor {
    private trackProcessor;
    private stats;
    private wasm?;
    private focusMask;
    private isOptionsUpdated;
    /**
     * {@link LightAdjustmentProcessor} インスタンスを生成します
     */
    constructor();
    /**
     * 実行環境が必要な機能をサポートしているかどうかを判定します
     *
     * 以下のいずれかが利用可能である必要があります:
     * - MediaStreamTrack Insertable Streams (aka. Breakout Box)
     * - HTMLVideoElement.requestVideoFrameCallback
     *
     * @returns サポートされているかどうか
     */
    static isSupported(): boolean;
    /**
     * ライト調整処理の適用を開始します
     *
     * @param track 処理適用対象となる映像トラック
     * @param options 各種オプション
     *
     * @returns 処理適用後の映像トラック
     *
     * @throws
     * 既にあるトラックを処理中の場合には、エラーが送出されます
     *
     * 処理中かどうかは {@link LightAdjustmentProcessor.isProcessing} で判定可能です
     */
    startProcessing(track: MediaStreamVideoTrack, options?: LightAdjustmentProcessorOptions): Promise<MediaStreamVideoTrack>;
    private processImage;
    /**
     * ライト調整処理の適用を停止します
     *
     * コンストラクタに渡された映像トラックは閉じないので、
     * 必要であれば、別途呼び出し側で対処する必要があります
     */
    stopProcessing(): void;
    /**
     * ライト調整処理が実行中かどうかを判定します
     *
     * @returns 実行中であれば `true` 、そうでなければ `false`
     */
    isProcessing(): boolean;
    /**
     * 処理適用前の映像トラックを返します
     *
     * これは {@link LightAdjustmentProcessor.startProcessing} に渡したトラックと等しいです
     *
     * {@link LightAdjustmentProcessor.startProcessing} 呼び出し前、あるいは、
     * {@link LightAdjustmentProcessor.stopProcessing} 呼び出し後には `undefined` が返されます
     *
     * @returns 処理適用中の場合は映像トラック、それ以外なら `undefined`
     */
    getOriginalTrack(): MediaStreamVideoTrack | undefined;
    /**
     * 処理適用後の映像トラックを返します
     *
     * これは {@link LightAdjustmentProcessor.startProcessing} が返したトラックと等しいです
     *
     * {@link LightAdjustmentProcessor.startProcessing} 呼び出し前、あるいは、
     * {@link LightAdjustmentProcessor.stopProcessing} 呼び出し後には `undefined` が返されます
     *
     * @returns 処理適用中の場合は映像トラック、それ以外なら `undefined`
     */
    getProcessedTrack(): MediaStreamVideoTrack | undefined;
    /**
     * 適用中の処理のオプションを更新します
     *
     * 処理が適用中ではない場合には、このメソッド呼び出しは単に無視されます
     *
     * @param options 更新対象のオプション。省略された項目については現在の値がそのまま使用されます。
     */
    updateOptions(options: LightAdjustmentProcessorOptions): void;
    /**
     * 適用中の処理の現在の統計値を取得します
     *
     * @returns 統計値オブジェクト
     */
    getStats(): LightAdjustmentProcessorStats;
    /**
     * 統計値を初期化します
     */
    resetStats(): void;
    /**
     * VideoTrackProcessorで計算したFPSを取得します
     */
    getFps(): number;
    /**
     * VideoTrackProcessorで計算した平均処理時間を取得します
     */
    getAverageProcessedTimeMs(): number;
}
/**
 * ライト調整処理の各種統計値
 */
declare class LightAdjustmentProcessorStats {
    /**
     * 処理した映像フレームの合計数
     */
    totalProcessedFrames: number;
    /**
     * 映像フレームの処理に要した合計時間（ミリ秒単位）
     */
    totalProcessedTimeMs: number;
    /**
     * ライト調整用の変換テーブルを更新した数
     */
    totalUpdateStateCount: number;
    /**
     * 映像フレームの処理に要した時間の平均値を取得します
     *
     * @returns ミリ秒単位の平均所要時間
     */
    getAverageProcessedTimeMs(): number;
    /**
     * 統計値を初期化します
     */
    reset(): void;
}
/**
 * ライト調整の際に画像のどの領域を基準にするかを指定するためのインタフェース。
 */
interface FocusMask {
    /**
     * ライト調整の際にフォーカスする領域を示すマスク配列を返す。
     *
     * 返り値の各バイトは画像の一つのピクセルに対応し、値はそのピクセルの重みを表す。
     * 重みが大きいピクセルほど、ライト調整の際により適切な明るさになるように処理される。
     *
     * なお、このメソッドが返すマスク配列はあくまでも「画像（の明るさ）をどのように調整するか」を
     * 左右するだけであり、ライト調整処理自体は常に画像全体に適用される。
     *
     * @param options 処理対象となる入力画像
     * @returns フォーカス領域を示すバイト列
     */
    getFocusMask(image: ImageData): Promise<Uint8Array>;
}
/**
 * 画像全体を均等に扱うフォーカスマスク。
 */
declare class UniformFocusMask implements FocusMask {
    private mask;
    getFocusMask(image: ImageData): Promise<Uint8Array>;
}
/**
 * 画像全体を九分割して、その中央部分にフォーカスするマスク。
 */
declare class CenterFocusMask implements FocusMask {
    private mask;
    getFocusMask(image: ImageData): Promise<Uint8Array>;
}
/**
 * 画像内の人物部分にフォーカスするマスク。
 *
 * 画像から人物領域をセグメンテーションするためには
 * @mediapipe/selfie-segmentation パッケージを使用している。
 */
declare class SelfieSegmentationFocusMask implements FocusMask {
    private segmentation;
    private mask;
    private canvas;
    private canvasCtx;
    /**
     * {@link SelfieSegmentationFocusMask} インスタンスを生成する。
     *
     * @param assetsPath @mediapipe/selfie-segmentation のアセットファイル（.wasm や .tflite）が配置されているパス
     */
    constructor(assetsPath: string);
    getFocusMask(image: ImageData): Promise<Uint8Array>;
    private processSegmentationResults;
}
export { LightAdjustmentProcessor, LightAdjustmentProcessorStats, type LightAdjustmentProcessorOptions, type FocusMask, UniformFocusMask, CenterFocusMask, SelfieSegmentationFocusMask, };
